@@ -4,6 +4,7 @@ NGSI LD models for context broker interaction
 
 import logging
 from typing import Any, List, Dict, Union, Optional
+import re
 from geojson_pydantic import (
     Point,
     MultiPoint,
@@ -93,7 +94,7 @@ class ContextProperty(BaseModel):
     )
     field_validator("modifiedAt")(validate_fiware_datatype_string_protect)
 
-    UnitCode: Optional[str] = Field(
+    unitCode: Optional[str] = Field(
         None,
         title="Unit Code",
         description="Representing the unit of the value. "
@@ -103,7 +104,7 @@ class ContextProperty(BaseModel):
         max_length=256,
         min_length=1,
     )
-    field_validator("UnitCode")(validate_fiware_datatype_string_protect)
+    field_validator("unitCode")(validate_fiware_datatype_string_protect)
 
     datasetId: Optional[str] = Field(
         None,
@@ -369,7 +370,7 @@ class NamedContextRelationship(ContextRelationship):
     field_validator("name")(validate_fiware_datatype_string_protect)
 
 
-class ContextLDEntityKeyValues(BaseModel):
+class ContextLDEntityBase(BaseModel):
     """
     Base Model for an entity is represented by a JSON object with the following
     syntax.
@@ -379,7 +380,6 @@ class ContextLDEntityKeyValues(BaseModel):
 
     The entity type is specified by the object's type property, whose value
     is a string containing the entity's type name.
-
     """
 
     model_config = ConfigDict(
@@ -414,6 +414,59 @@ class ContextLDEntityKeyValues(BaseModel):
         frozen=True,
     )
     field_validator("type")(validate_fiware_standard_regex)
+    context: Optional[Union[str, List[str], Dict]] = Field(
+        title="@context",
+        default=None,
+        description="The @context in JSON-LD is used to expand terms, provided as short "
+        "hand strings, to concepts, specified as URIs, and vice versa, "
+        "to compact URIs into terms "
+        "The main implication of NGSI-LD API is that if the @context is "
+        "a compound one, i.e. an @context which references multiple "
+        "individual @context, served by resources behind different URIs, "
+        "then a wrapper @context has to be created and hosted.",
+        examples=["https://n5geh.github.io/n5geh.test-context.io/context_saref.jsonld"],
+        alias="@context",
+        validation_alias="@context",
+        frozen=False,
+    )
+
+
+class ContextLDEntityKeyValues(ContextLDEntityBase):
+    """
+    Base Model for an entity is represented by a JSON object with the following
+    syntax.
+
+    The entity id is specified by the object's id property, whose value
+    is a string containing the entity id.
+
+    The entity type is specified by the object's type property, whose value
+    is a string containing the entity's type name.
+
+    """
+
+    model_config = ConfigDict(
+        extra="allow", validate_default=True, validate_assignment=True
+    )
+
+    def to_entity(self):
+        """
+        Convert the entity to a normalized representation.
+        """
+        return ContextLDEntity(
+            **{
+                "id": self.id,
+                "type": self.type,
+                "context": self.context if self.context else None,
+                **{
+                    key: {
+                        "type": "Property",
+                        "value": value,
+                    }
+                    for key, value in self.model_dump().items()
+                    if key not in ["id", "type", "context"]
+                },
+            }
+        )
 
 
 class PropertyFormat(str, Enum):
@@ -426,7 +479,7 @@ class PropertyFormat(str, Enum):
     DICT = "dict"
 
 
-class ContextLDEntity(ContextLDEntityKeyValues):
+class ContextLDEntity(ContextLDEntityBase):
     """
     Context LD entities, or simply entities, are the center of gravity in the
     FIWARE NGSI-LD information model. An entity represents a thing, i.e., any
@@ -478,21 +531,6 @@ class ContextLDEntity(ContextLDEntityKeyValues):
         "observationspace are different and "
         "can be disjoint. ",
     )
-    context: Optional[Union[str, List[str], Dict]] = Field(
-        title="@context",
-        default=None,
-        description="The @context in JSON-LD is used to expand terms, provided as short "
-        "hand strings, to concepts, specified as URIs, and vice versa, "
-        "to compact URIs into terms "
-        "The main implication of NGSI-LD API is that if the @context is "
-        "a compound one, i.e. an @context which references multiple "
-        "individual @context, served by resources behind different URIs, "
-        "then a wrapper @context has to be created and hosted.",
-        examples=["https://n5geh.github.io/n5geh.test-context.io/context_saref.jsonld"],
-        alias="@context",
-        validation_alias="@context",
-        frozen=False,
-    )
 
     @field_validator("context")
     @classmethod
@@ -797,6 +835,16 @@ class ContextLDEntity(ContextLDEntityKeyValues):
         else:
             return context
 
+    def to_keyvalues(self) -> ContextLDEntityKeyValues:
+        props = self.get_properties()
+        rels = self.get_relationships()
+        result = dict[str, Any]()
+        for prop in props:
+            result[prop.name] = prop.value
+        for rel in rels:
+            result[rel.name] = rel.object
+        return ContextLDEntityKeyValues(id=self.id, type=self.type, **result)
+
 
 class ActionTypeLD(str, Enum):
     """
@@ -818,3 +866,22 @@ class UpdateLD(BaseModel):
         description="an array of entities, each entity specified using the "
         "JSON entity representation format "
     )
+
+
+class MessageLD(BaseModel):
+    """
+    Model for a notification message, when sent to other NGSIv2-APIs
+    """
+
+    subscriptionId: Optional[str] = Field(
+        default=None,
+        description="Id of the subscription the notification comes from",
+    )
+    data: List[ContextLDEntity] = Field(
+        description="is an array with the notification data itself which "
+        "includes the entity and all concerned attributes. Each "
+        "element in the array corresponds to a different entity. "
+        "By default, the entities are represented in normalized "
+        "mode. However, using the attrsFormat modifier, a "
+        "simplified representation mode can be requested."
+    )
