@@ -2,18 +2,19 @@
 
 from enum import Enum
 from pydantic import BaseModel, Field
-from typing import List, TYPE_CHECKING, Dict, Union, Set
+from typing import List, TYPE_CHECKING, Dict, Union, Set, Any
 
 from .source import DependencyStatement
 
 if TYPE_CHECKING:
-    from . import \
-        CombinedObjectRelation, \
-        CombinedDataRelation, \
-        CombinedRelation, \
-        Relation, \
-        Vocabulary, \
-        Source
+    from . import (
+        CombinedObjectRelation,
+        CombinedDataRelation,
+        CombinedRelation,
+        Relation,
+        Vocabulary,
+        Source,
+    )
 
 
 class Entity(BaseModel):
@@ -27,28 +28,32 @@ class Entity(BaseModel):
     field key. The user can overwrite the given
     label
     """
+
     iri: str = Field(description="Unique Internationalized Resource Identifier")
     label: str = Field(
         default="",
         description="Label (displayname) extracted from source file "
-                    "(multiple Entities could have the same label)")
-    user_set_label = Field(
+        "(multiple Entities could have the same label)",
+    )
+    user_set_label: Any = Field(
         default="",
         description="Given by user and overwrites 'label'."
-                    " Needed to make labels unique")
+        " Needed to make labels unique",
+    )
     comment: str = Field(
-        default="",
-        description="Comment extracted from the ontology/source")
+        default="", description="Comment extracted from the ontology/source"
+    )
     source_ids: Set[str] = Field(
-        default=set(),
-        description="IDs of the sources that influenced this class")
+        default=set(), description="IDs of the sources that influenced this class"
+    )
     predefined: bool = Field(
         default=False,
         description="Stats if the entity is not extracted from a source, "
-                    "but predefined in the program (Standard Datatypes)")
+        "but predefined in the program (Standard Datatypes)",
+    )
 
     def get_label(self) -> str:
-        """ Get the label for the entity.
+        """Get the label for the entity.
         If the user has set a label it is returned, else the label extracted
         from the source
 
@@ -60,8 +65,8 @@ class Entity(BaseModel):
 
         return self.get_original_label()
 
-    def set_label(self, label:str):
-        """ Change the display label of the entity
+    def set_label(self, label: str):
+        """Change the display label of the entity
 
         Args:
             label (str): Label that the label should have
@@ -69,7 +74,7 @@ class Entity(BaseModel):
         self.user_set_label = label
 
     def get_ontology_iri(self) -> str:
-        """ Get the IRI of the ontology that this entity belongs to
+        """Get the IRI of the ontology that this entity belongs to
         (extracted from IRI)
 
         Returns:
@@ -78,8 +83,8 @@ class Entity(BaseModel):
         index = self.iri.find("#")
         return self.iri[:index]
 
-    def get_source_names(self, vocabulary: 'Vocabulary') -> List[str]:
-        """ Get the names of all the sources
+    def get_source_names(self, vocabulary: "Vocabulary") -> List[str]:
+        """Get the names of all the sources
 
         Args:
             vocabulary (Vocabulary): Vocabulary of the project
@@ -87,13 +92,12 @@ class Entity(BaseModel):
         Returns:
             str
         """
-        names = [vocabulary.get_source(id).get_name() for
-                 id in self.source_ids]
+        names = [vocabulary.get_source(id).get_name() for id in self.source_ids]
 
         return names
 
-    def get_sources(self, vocabulary: 'Vocabulary') -> List['Source']:
-        """ Get all the source objects that influenced this entity.
+    def get_sources(self, vocabulary: "Vocabulary") -> List["Source"]:
+        """Get all the source objects that influenced this entity.
         The sources are sorted according to their names
 
         Args:
@@ -109,7 +113,7 @@ class Entity(BaseModel):
         return sources
 
     def _lists_are_identical(self, a: List, b: List) -> bool:
-        """ Methode to test if to lists contain the same entries
+        """Methode to test if to lists contain the same entries
 
         Args:
             a (List): first list
@@ -120,7 +124,7 @@ class Entity(BaseModel):
         return len(set(a).intersection(b)) == len(set(a)) and len(a) == len(b)
 
     def is_renamed(self) -> bool:
-        """ Check if the entity was renamed by the user
+        """Check if the entity was renamed by the user
 
         Returns:
             bool
@@ -128,7 +132,7 @@ class Entity(BaseModel):
         return not self.user_set_label == ""
 
     def get_original_label(self) -> str:
-        """ Get label as defined in the source
+        """Get label as defined in the source
         It can be that the label is empty, then extract the label from the iri
 
         Returns:
@@ -155,24 +159,27 @@ class Class(Entity):
     # The objects whose ids/iris are listed here can be looked up in the
     # vocabulary of this class
     child_class_iris: List[str] = Field(
-        default=[],
-        description="All class_iris of classes that inherit from this class")
+        default=[], description="All class_iris of classes that inherit from this class"
+    )
     ancestor_class_iris: List[str] = Field(
         default=[],
-        description="All class_iris of classes from which this class inherits")
+        description="All class_iris of classes from which this class inherits",
+    )
     parent_class_iris: List[str] = Field(
         default=[],
         description="All class_iris of classes that are direct parents of this "
-                    "class")
+        "class",
+    )
     relation_ids: List[str] = Field(
-        default=[],
-        description="All ids of relations defined for this class")
+        default=[], description="All ids of relations defined for this class"
+    )
     combined_object_relation_ids: List[str] = Field(
         default=[],
-        description="All combined_object_relations ids defined for this class")
+        description="All combined_object_relations ids defined for this class",
+    )
     combined_data_relation_ids: List[str] = Field(
-        default=[],
-        description="All combined_data_relations ids defined for this class")
+        default=[], description="All combined_data_relations ids defined for this class"
+    )
 
     def get_relation_ids(self) -> List[str]:
         """Get all ids of relations belonging to this class
@@ -182,7 +189,7 @@ class Class(Entity):
         """
         return self.relation_ids
 
-    def get_relations(self, vocabulary: 'Vocabulary') -> List['Relation']:
+    def get_relations(self, vocabulary: "Vocabulary") -> List["Relation"]:
         """Get all relations belonging to this class
 
         Args:
@@ -197,8 +204,9 @@ class Class(Entity):
 
         return result
 
-    def get_combined_object_relations(self, vocabulary: 'Vocabulary') -> \
-            List['CombinedObjectRelation']:
+    def get_combined_object_relations(
+        self, vocabulary: "Vocabulary"
+    ) -> List["CombinedObjectRelation"]:
         """Get all combined object relations belonging to this class
 
         Args:
@@ -214,8 +222,9 @@ class Class(Entity):
 
         return result
 
-    def get_combined_data_relations(self, vocabulary: 'Vocabulary') -> \
-            List['CombinedDataRelation']:
+    def get_combined_data_relations(
+        self, vocabulary: "Vocabulary"
+    ) -> List["CombinedDataRelation"]:
         """Get all combined data relations belonging to this class
 
         Args:
@@ -231,8 +240,9 @@ class Class(Entity):
 
         return result
 
-    def get_combined_relations(self, vocabulary: 'Vocabulary') -> \
-            List['CombinedRelation']:
+    def get_combined_relations(
+        self, vocabulary: "Vocabulary"
+    ) -> List["CombinedRelation"]:
         """Get all combined relations belonging to this class
 
         Args:
@@ -263,8 +273,8 @@ class Class(Entity):
         return True
 
     def get_combined_object_relation_with_property_iri(
-            self, obj_prop_iri: str, vocabulary: 'Vocabulary') \
-            -> 'CombinedObjectRelation':
+        self, obj_prop_iri: str, vocabulary: "Vocabulary"
+    ) -> "CombinedObjectRelation":
         """
         Get the CombinedObjectRelation of this class that combines the
         relations of the given ObjectProperty
@@ -281,8 +291,7 @@ class Class(Entity):
                 return cor
         return None
 
-    def get_combined_data_relation_with_property_iri(self, property_iri,
-                                                     vocabulary):
+    def get_combined_data_relation_with_property_iri(self, property_iri, vocabulary):
         """
         Get the CombinedDataRelation of this class that combines the
         relations of the given DataProperty
@@ -299,8 +308,9 @@ class Class(Entity):
                 return cdr
         return None
 
-    def get_combined_relation_with_property_iri(self, property_iri, vocabulary)\
-            -> Union['CombinedRelation', None]:
+    def get_combined_relation_with_property_iri(
+        self, property_iri, vocabulary
+    ) -> Union["CombinedRelation", None]:
         """
         Get the CombinedRelation of this class that combines the relations
         of the given Property
@@ -313,7 +323,7 @@ class Class(Entity):
 
         Returns:
             CombinedRelation, None if iri is unknown
-       """
+        """
         for cdr in self.get_combined_data_relations(vocabulary):
             if cdr.property_iri == property_iri:
                 return cdr
@@ -322,7 +332,7 @@ class Class(Entity):
                 return cor
         return None
 
-    def get_ancestor_classes(self, vocabulary: 'Vocabulary') -> List['Class']:
+    def get_ancestor_classes(self, vocabulary: "Vocabulary") -> List["Class"]:
         """Get all ancestor classes of this class
 
         Args:
@@ -336,9 +346,9 @@ class Class(Entity):
             ancestors.append(vocabulary.get_class_by_iri(ancestor_iri))
         return ancestors
 
-    def get_parent_classes(self,
-                           vocabulary: 'Vocabulary',
-                           remove_redundancy: bool = False) -> List['Class']:
+    def get_parent_classes(
+        self, vocabulary: "Vocabulary", remove_redundancy: bool = False
+    ) -> List["Class"]:
         """Get all parent classes of this class
 
         Args:
@@ -364,8 +374,9 @@ class Class(Entity):
 
         return parents
 
-    def treat_dependency_statements(self, vocabulary: 'Vocabulary') -> \
-            List[DependencyStatement]:
+    def treat_dependency_statements(
+        self, vocabulary: "Vocabulary"
+    ) -> List[DependencyStatement]:
         """
         Purge and list all pointers/iris that are not contained in
         the vocabulary
@@ -383,11 +394,14 @@ class Class(Entity):
         parents_to_purge = []
         for parent_iri in self.parent_class_iris:
             found = parent_iri in vocabulary.classes
-            statements.append(DependencyStatement(type="Parent Class",
-                                                  class_iri=self.iri,
-                                                  dependency_iri=parent_iri,
-                                                  fulfilled=found
-                                                  ))
+            statements.append(
+                DependencyStatement(
+                    type="Parent Class",
+                    class_iri=self.iri,
+                    dependency_iri=parent_iri,
+                    fulfilled=found,
+                )
+            )
             if not found:
                 parents_to_purge.append(parent_iri)
         for iri in parents_to_purge:
@@ -398,7 +412,8 @@ class Class(Entity):
         for relation in self.get_relations(vocabulary):
 
             relation_statements = relation.get_dependency_statements(
-                vocabulary, self.get_ontology_iri(), self.iri)
+                vocabulary, self.get_ontology_iri(), self.iri
+            )
             for statement in relation_statements:
                 if statement.fulfilled == False:
                     relation_ids_to_purge.add(relation.id)
@@ -410,8 +425,9 @@ class Class(Entity):
 
         return statements
 
-    def get_next_combined_relation_id(self, current_cr_id: str,
-                                      object_relations: bool) -> str:
+    def get_next_combined_relation_id(
+        self, current_cr_id: str, object_relations: bool
+    ) -> str:
         """Get the alphabetically(Property label) next CombinedRelation.
 
         If no CR is after the given one, the first is returned
@@ -430,13 +446,14 @@ class Class(Entity):
             list_ = self.combined_object_relation_ids
 
         current_index = list_.index(current_cr_id)
-        res_index = current_index+1
+        res_index = current_index + 1
         if res_index >= len(list_):
             res_index = 0
         return list_[res_index]
 
-    def get_previous_combined_relation_id(self, current_cr_id: str,
-                                          object_relations: bool) -> str:
+    def get_previous_combined_relation_id(
+        self, current_cr_id: str, object_relations: bool
+    ) -> str:
         """Get the alphabetically(Property label) previous CombinedRelation.
 
         If no CR is before the given one, the last is returned
@@ -458,12 +475,12 @@ class Class(Entity):
         current_index = list_.index(current_cr_id)
         res_index = current_index - 1
         if res_index < 0:
-            res_index = len(list_)-1
+            res_index = len(list_) - 1
         return list_[res_index]
 
-    def is_logically_equivalent_to(self, class_: 'Class',
-                                   vocabulary: 'Vocabulary',
-                                   old_vocabulary: 'Vocabulary') -> bool:
+    def is_logically_equivalent_to(
+        self, class_: "Class", vocabulary: "Vocabulary", old_vocabulary: "Vocabulary"
+    ) -> bool:
         """Test if a class is logically equivalent in two vocabularies.
 
         Args:
@@ -476,18 +493,21 @@ class Class(Entity):
         """
 
         # test if parent classes are identical
-        if not self._lists_are_identical(class_.parent_class_iris,
-                                         self.parent_class_iris):
+        if not self._lists_are_identical(
+            class_.parent_class_iris, self.parent_class_iris
+        ):
             return False
 
         # test if combined object relation ids are identical
-        if not self._lists_are_identical(class_.combined_object_relation_ids,
-                                         self.combined_object_relation_ids):
+        if not self._lists_are_identical(
+            class_.combined_object_relation_ids, self.combined_object_relation_ids
+        ):
             return False
 
         # test if combined data  relation ids are identical
-        if not self._lists_are_identical(class_.combined_data_relation_ids,
-                                         self.combined_data_relation_ids):
+        if not self._lists_are_identical(
+            class_.combined_data_relation_ids, self.combined_data_relation_ids
+        ):
             return False
 
         # test if combined relations are identical
@@ -502,14 +522,13 @@ class Class(Entity):
             for old_relation in old_cr.get_relations(old_vocabulary):
                 old_relation_strings.append(old_relation.to_string(vocabulary))
 
-            if not self._lists_are_identical(relation_strings,
-                                             old_relation_strings):
+            if not self._lists_are_identical(relation_strings, old_relation_strings):
 
                 return False
 
         return True
 
-    def is_iot_class(self, vocabulary: 'Vocabulary') -> bool:
+    def is_iot_class(self, vocabulary: "Vocabulary") -> bool:
         """
         A class is an iot/device class if it contains one CDR, where the
         relation is marked as a device relation: DeviceAttribute/Command
@@ -533,39 +552,42 @@ class DatatypeType(str, Enum):
     """
     Types of a Datatype
     """
-    string = 'string'
-    number = 'number'
-    date = 'date'
-    enum = 'enum'
+
+    string = "string"
+    number = "number"
+    date = "date"
+    enum = "enum"
 
 
 class DatatypeFields(BaseModel):
     """Key Fields describing a Datatype"""
-    type: DatatypeType = Field(default=DatatypeType.string,
-                               description="Type of the datatype")
-    number_has_range = Field(
-        default=False,
-        description="If Type==Number: Does the datatype define a range")
+
+    type: DatatypeType = Field(
+        default=DatatypeType.string, description="Type of the datatype"
+    )
+    number_has_range: Any = Field(
+        default=False, description="If Type==Number: Does the datatype define a range"
+    )
     number_range_min: Union[int, str] = Field(
         default="/",
         description="If Type==Number: Min value of the datatype range, "
-                    "if a range is defined")
+        "if a range is defined",
+    )
     number_range_max: Union[int, str] = Field(
         default="/",
         description="If Type==Number: Max value of the datatype range, "
-                    "if a range is defined")
+        "if a range is defined",
+    )
     number_decimal_allowed: bool = Field(
-        default=False,
-        description="If Type==Number: Are decimal numbers allowed?")
+        default=False, description="If Type==Number: Are decimal numbers allowed?"
+    )
     forbidden_chars: List[str] = Field(
-        default=[],
-        description="If Type==String: Blacklisted chars")
+        default=[], description="If Type==String: Blacklisted chars"
+    )
     allowed_chars: List[str] = Field(
-        default=[],
-        description="If Type==String: Whitelisted chars")
-    enum_values: List[str] = Field(
-        default=[],
-        description="If Type==Enum: Enum values")
+        default=[], description="If Type==String: Whitelisted chars"
+    )
+    enum_values: List[str] = Field(default=[], description="If Type==Enum: Enum values")
 
 
 class Datatype(Entity, DatatypeFields):
@@ -580,21 +602,26 @@ class Datatype(Entity, DatatypeFields):
     vocabulary
     """
 
-    def export(self) -> Dict[str,str]:
-        """ Export datatype as dict
+    def export(self) -> Dict[str, str]:
+        """Export datatype as dict
 
         Returns:
             Dict[str,str]
         """
-        res = self.dict(include={'type', 'number_has_range',
-                                 'number_range_min', 'number_range_max',
-                                 'number_decimal_allowed', 'forbidden_chars',
-                                 'allowed_chars', 'enum_values'},
-                        exclude_defaults={'type', 'number_has_range',
-                                 'number_range_min', 'number_range_max',
-                                 'number_decimal_allowed', 'forbidden_chars',
-                                 'allowed_chars', 'enum_values'})
-        res['type'] = self.type.value
+        res = self.model_dump(
+            include={
+                "type",
+                "number_has_range",
+                "number_range_min",
+                "number_range_max",
+                "number_decimal_allowed",
+                "forbidden_chars",
+                "allowed_chars",
+                "enum_values",
+            },
+            exclude_defaults=True,
+        )
+        res["type"] = self.type.value
         return res
 
     def value_is_valid(self, value: str) -> bool:
@@ -647,6 +674,7 @@ class Datatype(Entity, DatatypeFields):
         if self.type == DatatypeType.date:
             try:
                 from dateutil.parser import parse
+
                 parse(value, fuzzy=False)
                 return True
 
@@ -655,9 +683,12 @@ class Datatype(Entity, DatatypeFields):
 
         return True
 
-    def is_logically_equivalent_to(self, datatype:'Datatype',
-                                   vocabulary: 'Vocabulary',
-                                   old_vocabulary: 'Vocabulary') -> bool:
+    def is_logically_equivalent_to(
+        self,
+        datatype: "Datatype",
+        vocabulary: "Vocabulary",
+        old_vocabulary: "Vocabulary",
+    ) -> bool:
         """Test if this datatype is logically equivalent to the given datatype
 
         Args:
@@ -694,7 +725,8 @@ class Individual(Entity):
     parent_class_iris: List[str] = Field(
         default=[],
         description="List of all parent class iris, "
-                    "an individual can have multiple parents")
+        "an individual can have multiple parents",
+    )
 
     def to_string(self) -> str:
         """Get a string representation of the Individual
@@ -702,10 +734,10 @@ class Individual(Entity):
         Returns:
             str
         """
-        return "(Individual)"+self.get_label()
+        return "(Individual)" + self.get_label()
 
-    def get_ancestor_iris(self, vocabulary: 'Vocabulary') -> List[str]:
-        """ Get all iris of ancestor classes
+    def get_ancestor_iris(self, vocabulary: "Vocabulary") -> List[str]:
+        """Get all iris of ancestor classes
 
         Args:
             vocabulary (Vocabulary): Vocabulary of the project
@@ -716,13 +748,14 @@ class Individual(Entity):
         ancestor_iris = set()
         for parent_iri in self.parent_class_iris:
             ancestor_iris.add(parent_iri)
-            ancestor_iris.update(vocabulary.get_class_by_iri(parent_iri).
-                                 ancestor_class_iris)
+            ancestor_iris.update(
+                vocabulary.get_class_by_iri(parent_iri).ancestor_class_iris
+            )
 
         return list(ancestor_iris)
 
-    def get_parent_classes(self, vocabulary: 'Vocabulary') -> List['Class']:
-        """ Get all parent class objects
+    def get_parent_classes(self, vocabulary: "Vocabulary") -> List["Class"]:
+        """Get all parent class objects
 
         Args:
             vocabulary (Vocabulary): Vocabulary of the project
@@ -735,9 +768,12 @@ class Individual(Entity):
             parents.append(vocabulary.get_class_by_iri(parent_iri))
         return parents
 
-    def is_logically_equivalent_to(self, individual: 'Individual',
-                                   vocabulary: 'Vocabulary',
-                                   old_vocabulary: 'Vocabulary') -> bool:
+    def is_logically_equivalent_to(
+        self,
+        individual: "Individual",
+        vocabulary: "Vocabulary",
+        old_vocabulary: "Vocabulary",
+    ) -> bool:
         """Test if this individal is logically equivalent in two vocabularies.
 
         Args:
@@ -752,14 +788,16 @@ class Individual(Entity):
             bool
         """
 
-        if not self._lists_are_identical(self.parent_class_iris,
-                                         individual.parent_class_iris):
+        if not self._lists_are_identical(
+            self.parent_class_iris, individual.parent_class_iris
+        ):
             return False
         return True
 
-    def treat_dependency_statements(self, vocabulary: 'Vocabulary') -> \
-            List[DependencyStatement]:
-        """ Purge and list all pointers/iris that are not contained in the
+    def treat_dependency_statements(
+        self, vocabulary: "Vocabulary"
+    ) -> List[DependencyStatement]:
+        """Purge and list all pointers/iris that are not contained in the
         vocabulary
 
         Args:
@@ -773,11 +811,14 @@ class Individual(Entity):
 
         for parent_iri in self.parent_class_iris:
             found = parent_iri in vocabulary.classes
-            statements.append(DependencyStatement(type="Parent Class",
-                                                  class_iri=self.iri,
-                                                  dependency_iri=parent_iri,
-                                                  fulfilled=found
-                                                  ))
+            statements.append(
+                DependencyStatement(
+                    type="Parent Class",
+                    class_iri=self.iri,
+                    dependency_iri=parent_iri,
+                    fulfilled=found,
+                )
+            )
 
             if not found:
                 self.parent_class_iris.remove(parent_iri)
@@ -787,6 +828,7 @@ class Individual(Entity):
 
 class DataFieldType(str, Enum):
     """Type of the field that represents the DataProperty"""
+
     command = "command"
     device_attribute = "device_attribute"
     simple = "simple"
@@ -800,7 +842,7 @@ class DataProperty(Entity):
     field_type: DataFieldType = Field(
         default=DataFieldType.simple,
         description="Type of the dataproperty; set by the user while "
-                    "configuring the vocabulary"
+        "configuring the vocabulary",
     )
 
 
@@ -812,9 +854,10 @@ class ObjectProperty(Entity):
     inverse_property_iris: Set[str] = Field(
         default=set(),
         description="List of property iris that are inverse:Of; "
-                    "If an instance i2 is added in an instance i1 "
-                    "for this property. Then i1 is added to i2 under the"
-                    " inverseProperty (if the class has that property)")
+        "If an instance i2 is added in an instance i1 "
+        "for this property. Then i1 is added to i2 under the"
+        " inverseProperty (if the class has that property)",
+    )
 
     def add_inverse_property_iri(self, iri: str):
         """Add an inverse property
@@ -827,9 +870,12 @@ class ObjectProperty(Entity):
         """
         self.inverse_property_iris.add(iri)
 
-    def is_logically_equivalent_to(self, object_property: 'ObjectProperty',
-                                   vocabulary: 'Vocabulary',
-                                   old_vocabulary: 'Vocabulary') -> bool:
+    def is_logically_equivalent_to(
+        self,
+        object_property: "ObjectProperty",
+        vocabulary: "Vocabulary",
+        old_vocabulary: "Vocabulary",
+    ) -> bool:
         """Test if this Property in the new_vocabulary is logically equivalent
         to the object_property in the old_vocabulary
 
@@ -844,8 +890,7 @@ class ObjectProperty(Entity):
         Returns:
             bool
         """
-        if not self.inverse_property_iris == \
-                object_property.inverse_property_iris:
+        if not self.inverse_property_iris == object_property.inverse_property_iris:
             return False
 
         return True
