@@ -1,7 +1,9 @@
 """
 Utility module for helper functions
 """
+
 from .validators import validate_http_url, validate_mqtt_url
-from .datetime import \
-    convert_datetime_to_iso_8601_with_z_suffix, \
-    transform_to_utc_datetime
+from .datetime import (
+    convert_datetime_to_iso_8601_with_z_suffix,
+    transform_to_utc_datetime,
+)
