@@ -1,26 +1,29 @@
 """
 Test module for configuration functions
 """
+
 import os
 import unittest
 from filip.config import Settings
+import json
+from pydantic import AnyHttpUrl
 
 
 class TestSettings(unittest.TestCase):
     """
     Test case for loading settings
     """
+
     def setUp(self) -> None:
 
         # Test if the testcase was run directly or over in a global test-run.
         # Match the needed path to the config file in both cases
         if os.getcwd().split("\\")[-1] == "tests":
-            self.settings_parsing = Settings(_env_file='test_config.env')
+            self.settings_parsing = Settings(_env_file="test_config.env")
         else:
-            self.settings_parsing = \
-                Settings(_env_file='./tests/test_config.env')
+            self.settings_parsing = Settings(_env_file="./tests/test_config.env")
 
-        for key, value in self.settings_parsing.dict().items():
+        for key, value in json.loads(self.settings_parsing.model_dump_json()).items():
             os.environ[key] = value
         self.settings_dotenv = Settings()
 
@@ -31,9 +34,15 @@ class TestSettings(unittest.TestCase):
         Returns:
             None
         """
-        self.assertEqual(self.settings_parsing.IOTA_URL, "http://myHost:4041")
-        self.assertEqual(self.settings_parsing.CB_URL, "http://myHost:1026")
-        self.assertEqual(self.settings_parsing.QL_URL, "http://myHost:8668")
+        self.assertEqual(
+            str(self.settings_parsing.IOTA_URL), str(AnyHttpUrl("http://myHost:4041/"))
+        )
+        self.assertEqual(
+            str(self.settings_parsing.CB_URL), str(AnyHttpUrl("http://myHost:1026/"))
+        )
+        self.assertEqual(
+            str(self.settings_parsing.QL_URL), str(AnyHttpUrl("http://myHost:8668/"))
+        )
 
     def test_example_dotenv(self):
         """
@@ -45,5 +54,5 @@ class TestSettings(unittest.TestCase):
         self.assertEqual(self.settings_parsing, self.settings_dotenv)
 
     def tearDown(self) -> None:
-        for k in self.settings_parsing.dict().keys():
+        for k in self.settings_parsing.model_dump().keys():
             del os.environ[k]
